# -*- coding:utf-8 -*-


class Field(object):
    pass


class IntegerField(Field):
    '''
    整数类型
    '''
    pass


class NumberField(Field):
    '''
    数字类型
    '''
    pass


class StringField(Field):
    '''
    字符串类型
    '''
    pass


class BoolField(Field):
    '''
    布尔类型
    '''
    pass


class Table(object):
    '''
    Schema基类
    '''

    pass


